==> labplot_1.3.1.1.orig.tar.gz: labplot-1.3.1.orig/src/ProjectDialog.cc <==
//LabPlot : ProjectDialog.cc

#include <stdlib.h>
#include <stdio.h>
#include <iostream>
#include <math.h>
#include <qlabel.h>
#include <qhbox.h>
#include <qfontdialog.h>
#include <klocale.h>
#include "ProjectDialog.h"

using namespace std;

ProjectDialog::ProjectDialog(Worksheet *p, const char *name)
	: Dialog(p, name),mw(p->getMainWin())
{
	setCaption(i18n("Project Settings"));

	project = mw->getProject();

	QHBox *hb = new QHBox(vbox);
	new QLabel(i18n("file name : "),hb);
	new QLabel(project->Filename(),hb);
	hb = new QHBox(vbox);
	new QLabel(i18n("project version : "),hb);
	new QLabel(QString::number(project->Version()),hb);
	new QLabel(i18n(" LabPlot version : "),hb);
	new QLabel(project->LabPlot(),hb);
	hb = new QHBox(vbox);
	new QLabel(i18n("title : "),hb);
	titlele = new KLineEdit(project->Title(),hb);
	hb = new QHBox(vbox);
	new QLabel(i18n("author : "),hb);
	authorle = new KLineEdit(project->Author(),hb);
	hb = new QHBox(vbox);
	new QLabel(i18n("created : "),hb);
	new QLabel(i18n(project->Created().toString()),hb);
	new QLabel(i18n(" last modified : "),hb);
	new QLabel(i18n(project->Modified().toString()),hb);
	hb = new QHBox(vbox);
	new QLabel(i18n(" comment : "),hb);
	commentle = new KLineEdit(project->Comment(),hb);

	QObject::connect(ok,SIGNAL(clicked()),SLOT(ok_clicked()));
	QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
	
	setMinimumSize(vbox->minimumSizeHint()+gbox->minimumSizeHint());
	resize(vbox->minimumSizeHint()+gbox->minimumSizeHint());
}

void ProjectDialog::apply_clicked() {
	project->setTitle(titlele->text());
	project->setAuthor(authorle->text());
	project->setComment(commentle->text());

	mw->setProject(project);
}

==> labplot_1.5.0.5.orig.tar.gz: labplot-1.5.0.orig/src/ProjectDialog.cc <==
//LabPlot : ProjectDialog.cc

#include <stdlib.h>
#include <stdio.h>
#include <iostream>
#include <math.h>
#include <qlabel.h>
#include <qhbox.h>
#include <qfontdialog.h>
#include <klocale.h>
#include "ProjectDialog.h"

using namespace std;

ProjectDialog::ProjectDialog(Worksheet *p, const char *name)
	: Dialog(p->getMainWin(), name),mw(p->getMainWin())
{
	setCaption(i18n("Project Settings"));

	project = mw->getProject();

	QHBox *hb = new QHBox(vbox);
	new QLabel(i18n("file name : "),hb);
	new QLabel(project->Filename(),hb);
	hb = new QHBox(vbox);
	new QLabel(i18n("project version : "),hb);
	new QLabel(QString::number(project->Version()),hb);
	new QLabel(i18n(" LabPlot version : "),hb);
	new QLabel(project->LabPlot(),hb);
	hb = new QHBox(vbox);
	new QLabel(i18n("title : "),hb);
	titlele = new KLineEdit(project->Title(),hb);
	hb = new QHBox(vbox);
	new QLabel(i18n("author : "),hb);
	authorle = new KLineEdit(project->Author(),hb);

	hb = new QHBox(vbox);
	new QLabel(i18n("created : "),hb);
#if KDE_VERSION > 0x030104
	created = new KDateTimeWidget(project->Created(),hb);
#else
	new QLabel(i18n(project->Created().toString()),hb);
#endif
	hb = new QHBox(vbox);
	new QLabel(i18n(" last modified : "),hb);
#if KDE_VERSION > 0x030104
	modified = new KDateTimeWidget(project->Modified(),hb);
#else
	new QLabel(i18n(project->Modified().toString()),hb);
#endif 

	hb = new QHBox(vbox);
	new QLabel(i18n(" comment : "),hb);
	commentle = new KLineEdit(project->Comment(),hb);

	QObject::connect(ok,SIGNAL(clicked()),SLOT(ok_clicked()));
	QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
	
	setMinimumWidth(vbox->minimumSizeHint().width());
	setMinimumHeight(gbox->minimumSizeHint().height()+vbox->minimumSizeHint().height());
	resize(minimumSize());
}

void ProjectDialog::apply_clicked() {
	project->setTitle(titlele->text());
	project->setAuthor(authorle->text());
	project->setComment(commentle->text());
	// not changable
//	project->setCreated(created->dateTime());
//	project->setModified(created->dateTime());
	
	mw->setProject(project);
}
